# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/wellknown/errors.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/wellknown/errors.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/wellknown/errors.proto\x12\x10\x65olymp.wellknown\" \n\x0b\x45rrorReport\x12\x11\n\treport_id\x18\x01 \x01(\t\"Z\n\x0fInvalidArgument\x12\x15\n\rargument_path\x18\x01 \x01(\t\x12\x30\n\nvalidation\x18\x02 \x03(\x0b\x32\x1c.eolymp.wellknown.Validation\"u\n\nValidation\x12\x15\n\rargument_path\x18\x01 \x03(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x39\n\x0clocalization\x18\x03 \x01(\x0b\x32#.eolymp.wellknown.ErrorLocalization\"-\n\rQuotaExceeded\x12\r\n\x05quota\x18\x01 \x01(\x05\x12\r\n\x05usage\x18\x02 \x01(\x05\"\xaa\x01\n\x11\x45rrorLocalization\x12\x12\n\nphrase_key\x18\x01 \x01(\t\x12L\n\rphrase_params\x18\x02 \x03(\x0b\x32\x35.eolymp.wellknown.ErrorLocalization.PhraseParamsEntry\x1a\x33\n\x11PhraseParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x35Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknownb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.wellknown.errors_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/wellknown;wellknown'
  _globals['_ERRORLOCALIZATION_PHRASEPARAMSENTRY']._loaded_options = None
  _globals['_ERRORLOCALIZATION_PHRASEPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_ERRORREPORT']._serialized_start=51
  _globals['_ERRORREPORT']._serialized_end=83
  _globals['_INVALIDARGUMENT']._serialized_start=85
  _globals['_INVALIDARGUMENT']._serialized_end=175
  _globals['_VALIDATION']._serialized_start=177
  _globals['_VALIDATION']._serialized_end=294
  _globals['_QUOTAEXCEEDED']._serialized_start=296
  _globals['_QUOTAEXCEEDED']._serialized_end=341
  _globals['_ERRORLOCALIZATION']._serialized_start=344
  _globals['_ERRORLOCALIZATION']._serialized_end=514
  _globals['_ERRORLOCALIZATION_PHRASEPARAMSENTRY']._serialized_start=463
  _globals['_ERRORLOCALIZATION_PHRASEPARAMSENTRY']._serialized_end=514
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/content/fragment.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/content/fragment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/content/fragment.proto\x12\x0e\x65olymp.content\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbb\x03\n\x08\x46ragment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\n \x01(\t\x12\x0e\n\x06locale\x18\x0b \x01(\t\x12\r\n\x05\x64raft\x18\r \x01(\x08\x12\r\n\x05title\x18\x0c \x01(\t\x12$\n\x07\x63ontent\x18\x33 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12.\n\ncreated_at\x18< \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18= \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06labels\x18\x64 \x03(\t\"<\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x01\x12\x11\n\rCONTENT_VALUE\x10\x02\"\x92\x01\n\x05Patch\x12\x11\n\rUNKNOWN_PATCH\x10\x00\x12\r\n\tPATCH_ALL\x10\x01\x12\x0e\n\nPATCH_PATH\x10\x02\x12\x10\n\x0cPATCH_LOCALE\x10\x03\x12\x0f\n\x0bPATCH_DRAFT\x10\x05\x12\x0f\n\x0bPATCH_TITLE\x10\x06\x12\x11\n\rPATCH_CONTENT\x10\x07\x12\x10\n\x0cPATCH_LABELS\x10\x08\x42\x31Z/github.com/eolymp/go-sdk/eolymp/content;contentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.content.fragment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/content;content'
  _globals['_FRAGMENT']._serialized_start=109
  _globals['_FRAGMENT']._serialized_end=552
  _globals['_FRAGMENT_EXTRA']._serialized_start=343
  _globals['_FRAGMENT_EXTRA']._serialized_end=403
  _globals['_FRAGMENT_PATCH']._serialized_start=406
  _globals['_FRAGMENT_PATCH']._serialized_end=552
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Job(_message.Message):
    __slots__ = ("id", "type", "namespace", "status", "progress", "total", "inputs", "outputs", "created_at", "started_at", "progress_at", "complete_at", "logs_url")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN: _ClassVar[Job.Status]
        CREATED: _ClassVar[Job.Status]
        STARTED: _ClassVar[Job.Status]
        COMPLETE: _ClassVar[Job.Status]
        ERROR: _ClassVar[Job.Status]
    UNKNOWN: Job.Status
    CREATED: Job.Status
    STARTED: Job.Status
    COMPLETE: Job.Status
    ERROR: Job.Status
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_PATCH: _ClassVar[Job.Patch]
        PATCH_ALL: _ClassVar[Job.Patch]
        PATCH_PROGRESS: _ClassVar[Job.Patch]
        PATCH_OUTPUTS: _ClassVar[Job.Patch]
        PATCH_LOGS_URL: _ClassVar[Job.Patch]
        PATCH_STATUS: _ClassVar[Job.Patch]
    UNKNOWN_PATCH: Job.Patch
    PATCH_ALL: Job.Patch
    PATCH_PROGRESS: Job.Patch
    PATCH_OUTPUTS: Job.Patch
    PATCH_LOGS_URL: Job.Patch
    PATCH_STATUS: Job.Patch
    class InputsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class OutputsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_AT_FIELD_NUMBER: _ClassVar[int]
    LOGS_URL_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: str
    namespace: str
    status: Job.Status
    progress: int
    total: int
    inputs: _containers.ScalarMap[str, str]
    outputs: _containers.ScalarMap[str, str]
    created_at: _timestamp_pb2.Timestamp
    started_at: _timestamp_pb2.Timestamp
    progress_at: _timestamp_pb2.Timestamp
    complete_at: _timestamp_pb2.Timestamp
    logs_url: str
    def __init__(self, id: _Optional[str] = ..., type: _Optional[str] = ..., namespace: _Optional[str] = ..., status: _Optional[_Union[Job.Status, str]] = ..., progress: _Optional[int] = ..., total: _Optional[int] = ..., inputs: _Optional[_Mapping[str, str]] = ..., outputs: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., progress_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., logs_url: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/ecm/content.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/ecm/content.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import node_pb2 as eolymp_dot_ecm_dot_node__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/ecm/content.proto\x12\neolymp.ecm\x1a\x15\x65olymp/ecm/node.proto\"\x8a\x01\n\x07\x43ontent\x12\x0e\n\x04html\x18\x01 \x01(\tH\x00\x12\x0f\n\x05latex\x18\x02 \x01(\tH\x00\x12\x12\n\x08markdown\x18\x03 \x01(\tH\x00\x12\x1f\n\x03\x65\x63m\x18\x04 \x01(\x0b\x32\x10.eolymp.ecm.NodeH\x00\x12 \n\x06render\x18\x63 \x01(\x0b\x32\x10.eolymp.ecm.NodeB\x07\n\x05valueB)Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecmb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.ecm.content_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/ecm;ecm'
  _globals['_CONTENT']._serialized_start=64
  _globals['_CONTENT']._serialized_end=202
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/participant.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/participant.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.judge import medal_pb2 as eolymp_dot_judge_dot_medal__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/judge/participant.proto\x12\x0c\x65olymp.judge\x1a\x18\x65olymp/judge/medal.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd5\x04\n\x0bParticipant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x05 \x01(\t\x12\x12\n\nunofficial\x18\x06 \x01(\x08\x12\x10\n\x08inactive\x18\n \x01(\x08\x12\x14\n\x0c\x64isqualified\x18\x0b \x01(\x08\x12\r\n\x05ghost\x18\x08 \x01(\x08\x12\"\n\x05medal\x18\t \x01(\x0e\x32\x13.eolymp.judge.Medal\x12\x30\n\x06status\x18\x14 \x01(\x0e\x32 .eolymp.judge.Participant.Status\x12.\n\nstarted_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nstarted_in\x18\x16 \x01(\r\x12*\n\x06\x65nd_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x65nd_in\x18\x1a \x01(\r\x12\x12\n\nbonus_time\x18\x1b \x01(\r\x12\x10\n\x08passcode\x18\x1e \x01(\t\x12\x31\n\x07submits\x18( \x03(\x0b\x32 .eolymp.judge.Participant.Submit\x1a-\n\x06Submit\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\r\"h\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07WAITING\x10\x05\x12\t\n\x05READY\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\x0b\n\x07UPSOLVE\x10\x07\x12\x0b\n\x07\x42LOCKED\x10\x08\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.participant_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_PARTICIPANT']._serialized_start=108
  _globals['_PARTICIPANT']._serialized_end=705
  _globals['_PARTICIPANT_SUBMIT']._serialized_start=554
  _globals['_PARTICIPANT_SUBMIT']._serialized_end=599
  _globals['_PARTICIPANT_STATUS']._serialized_start=601
  _globals['_PARTICIPANT_STATUS']._serialized_end=705
# @@protoc_insertion_point(module_scope)



from eolymp.community import email_type_pb2 as _email_type_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Campaign(_message.Message):
    __slots__ = ("id", "type", "created_at", "subject", "content", "recipients_count", "pending_count", "sent_count", "error_count")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[Campaign.Patch]
        TYPE: _ClassVar[Campaign.Patch]
        SUBJECT: _ClassVar[Campaign.Patch]
        CONTENT: _ClassVar[Campaign.Patch]
        LOCALE: _ClassVar[Campaign.Patch]
    ALL: Campaign.Patch
    TYPE: Campaign.Patch
    SUBJECT: Campaign.Patch
    CONTENT: Campaign.Patch
    LOCALE: Campaign.Patch
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[Campaign.Extra]
        CONTENT_VALUE: _ClassVar[Campaign.Extra]
        CONTENT_RENDER: _ClassVar[Campaign.Extra]
    UNKNOWN_EXTRA: Campaign.Extra
    CONTENT_VALUE: Campaign.Extra
    CONTENT_RENDER: Campaign.Extra
    class Translation(_message.Message):
        __slots__ = ("id", "locale", "subject", "content", "automatic")
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        SUBJECT_FIELD_NUMBER: _ClassVar[int]
        CONTENT_FIELD_NUMBER: _ClassVar[int]
        AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
        id: str
        locale: str
        subject: str
        content: _content_pb2.Content
        automatic: bool
        def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., subject: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., automatic: bool = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_FIELD_NUMBER: _ClassVar[int]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    RECIPIENTS_COUNT_FIELD_NUMBER: _ClassVar[int]
    PENDING_COUNT_FIELD_NUMBER: _ClassVar[int]
    SENT_COUNT_FIELD_NUMBER: _ClassVar[int]
    ERROR_COUNT_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: _email_type_pb2.EmailType
    created_at: _timestamp_pb2.Timestamp
    subject: str
    content: _content_pb2.Content
    recipients_count: int
    pending_count: int
    sent_count: int
    error_count: int
    def __init__(self, id: _Optional[str] = ..., type: _Optional[_Union[_email_type_pb2.EmailType, str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., subject: _Optional[str] = ..., content: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., recipients_count: _Optional[int] = ..., pending_count: _Optional[int] = ..., sent_count: _Optional[int] = ..., error_count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/class.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/course/class.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/course/class.proto\x12\reolymp.course\";\n\x05\x43lass\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08group_id\x18\x03 \x01(\t\x12\x14\n\x0cmodule_count\x18\x06 \x01(\rB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.class_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_CLASS']._serialized_start=44
  _globals['_CLASS']._serialized_end=103
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/judge/announcement.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/judge/announcement.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/judge/announcement.proto\x12\x0c\x65olymp.judge\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd3\x01\n\x0c\x41nnouncement\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncontest_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07subject\x18\n \x01(\t\x12$\n\x07message\x18\x0b \x01(\x0b\x32\x13.eolymp.ecm.Content\"<\n\x05\x45xtra\x12\x0c\n\x08NO_EXTRA\x10\x00\x12\x12\n\x0eMESSAGE_RENDER\x10\x01\x12\x11\n\rMESSAGE_VALUE\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.announcement_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _globals['_ANNOUNCEMENT']._serialized_start=109
  _globals['_ANNOUNCEMENT']._serialized_end=320
  _globals['_ANNOUNCEMENT_EXTRA']._serialized_start=260
  _globals['_ANNOUNCEMENT_EXTRA']._serialized_end=320
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Quota(_message.Message):
    __slots__ = ("permissions_per_space", "single_sing_on", "dedicated_user_database", "attributes_per_space", "customer_support_reply_time", "allow_discussions", "achievements_per_space", "printers_per_space", "evaluations_by_seat_per_month", "priority_evaluation_queue", "plagiarism_analysis", "submission_evaluation_limit", "members_per_space", "campaigns_per_space", "emails_per_day", "emails_per_month", "scoreboards_per_space", "courses_per_space", "problems_per_space", "tests_per_problem", "testset_per_problem", "statement_per_problem", "editorial_per_problem", "solutions_per_problem", "code_templates_per_problem", "debug_assistant", "debug_hints_daily_per_admin", "debug_hints_daily_per_member", "contests_per_space", "active_contests_per_space", "contests_per_month", "problems_per_contest", "participants_per_contest", "contest_upsolve_mode", "max_contest_duration", "team_contests", "ghost_participants", "unofficial_participants")
    PERMISSIONS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    SINGLE_SING_ON_FIELD_NUMBER: _ClassVar[int]
    DEDICATED_USER_DATABASE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_SUPPORT_REPLY_TIME_FIELD_NUMBER: _ClassVar[int]
    ALLOW_DISCUSSIONS_FIELD_NUMBER: _ClassVar[int]
    ACHIEVEMENTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    PRINTERS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    EVALUATIONS_BY_SEAT_PER_MONTH_FIELD_NUMBER: _ClassVar[int]
    PRIORITY_EVALUATION_QUEUE_FIELD_NUMBER: _ClassVar[int]
    PLAGIARISM_ANALYSIS_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_EVALUATION_LIMIT_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    CAMPAIGNS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    EMAILS_PER_DAY_FIELD_NUMBER: _ClassVar[int]
    EMAILS_PER_MONTH_FIELD_NUMBER: _ClassVar[int]
    SCOREBOARDS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    COURSES_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    PROBLEMS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    TESTS_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    TESTSET_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    STATEMENT_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    EDITORIAL_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    SOLUTIONS_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    CODE_TEMPLATES_PER_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    DEBUG_ASSISTANT_FIELD_NUMBER: _ClassVar[int]
    DEBUG_HINTS_DAILY_PER_ADMIN_FIELD_NUMBER: _ClassVar[int]
    DEBUG_HINTS_DAILY_PER_MEMBER_FIELD_NUMBER: _ClassVar[int]
    CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_CONTESTS_PER_SPACE_FIELD_NUMBER: _ClassVar[int]
    CONTESTS_PER_MONTH_FIELD_NUMBER: _ClassVar[int]
    PROBLEMS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
    CONTEST_UPSOLVE_MODE_FIELD_NUMBER: _ClassVar[int]
    MAX_CONTEST_DURATION_FIELD_NUMBER: _ClassVar[int]
    TEAM_CONTESTS_FIELD_NUMBER: _ClassVar[int]
    GHOST_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    UNOFFICIAL_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    permissions_per_space: int
    single_sing_on: bool
    dedicated_user_database: bool
    attributes_per_space: int
    customer_support_reply_time: int
    allow_discussions: bool
    achievements_per_space: int
    printers_per_space: int
    evaluations_by_seat_per_month: int
    priority_evaluation_queue: bool
    plagiarism_analysis: bool
    submission_evaluation_limit: int
    members_per_space: int
    campaigns_per_space: int
    emails_per_day: int
    emails_per_month: int
    scoreboards_per_space: int
    courses_per_space: int
    problems_per_space: int
    tests_per_problem: int
    testset_per_problem: int
    statement_per_problem: int
    editorial_per_problem: int
    solutions_per_problem: int
    code_templates_per_problem: int
    debug_assistant: bool
    debug_hints_daily_per_admin: int
    debug_hints_daily_per_member: int
    contests_per_space: int
    active_contests_per_space: int
    contests_per_month: int
    problems_per_contest: int
    participants_per_contest: int
    contest_upsolve_mode: bool
    max_contest_duration: int
    team_contests: bool
    ghost_participants: bool
    unofficial_participants: bool
    def __init__(self, permissions_per_space: _Optional[int] = ..., single_sing_on: bool = ..., dedicated_user_database: bool = ..., attributes_per_space: _Optional[int] = ..., customer_support_reply_time: _Optional[int] = ..., allow_discussions: bool = ..., achievements_per_space: _Optional[int] = ..., printers_per_space: _Optional[int] = ..., evaluations_by_seat_per_month: _Optional[int] = ..., priority_evaluation_queue: bool = ..., plagiarism_analysis: bool = ..., submission_evaluation_limit: _Optional[int] = ..., members_per_space: _Optional[int] = ..., campaigns_per_space: _Optional[int] = ..., emails_per_day: _Optional[int] = ..., emails_per_month: _Optional[int] = ..., scoreboards_per_space: _Optional[int] = ..., courses_per_space: _Optional[int] = ..., problems_per_space: _Optional[int] = ..., tests_per_problem: _Optional[int] = ..., testset_per_problem: _Optional[int] = ..., statement_per_problem: _Optional[int] = ..., editorial_per_problem: _Optional[int] = ..., solutions_per_problem: _Optional[int] = ..., code_templates_per_problem: _Optional[int] = ..., debug_assistant: bool = ..., debug_hints_daily_per_admin: _Optional[int] = ..., debug_hints_daily_per_member: _Optional[int] = ..., contests_per_space: _Optional[int] = ..., active_contests_per_space: _Optional[int] = ..., contests_per_month: _Optional[int] = ..., problems_per_contest: _Optional[int] = ..., participants_per_contest: _Optional[int] = ..., contest_upsolve_mode: bool = ..., max_contest_duration: _Optional[int] = ..., team_contests: bool = ..., ghost_participants: bool = ..., unofficial_participants: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/course/submission_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/course/submission_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import submission_pb2 as eolymp_dot_atlas_dot_submission__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/course/submission_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/atlas/submission.proto\x1a!eolymp/wellknown/expression.proto\"M\n\x15\x43reateSubmissionInput\x12\x13\n\x0bmaterial_id\x18\x01 \x01(\t\x12\x0f\n\x07runtime\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\xcd\x04\n\x14ListSubmissionsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.course.ListSubmissionsInput.Filter\x1a\xda\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\t \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x33\n\x0bmaterial_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12;\n\x0csubmitted_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x31\n\x07runtime\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\x07verdict\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x08 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\"i\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Submission\x12\x18\n\x10next_page_cursor\x18\x04 \x01(\t\"0\n\x17\x44\x65scribeSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"H\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\"-\n\x14WatchSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"E\n\x15WatchSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission2\x87\x05\n\x11SubmissionService\x12\xa0\x01\n\x10\x43reateSubmission\x12$.eolymp.course.CreateSubmissionInput\x1a%.eolymp.course.CreateSubmissionOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xe3\n\x18\x8a\xe3\n\x14\x63ourse:course:submit\x82\xd3\xe4\x93\x02\x0e\"\x0c/submissions\x12\x9b\x01\n\x0fListSubmissions\x12#.eolymp.course.ListSubmissionsInput\x1a$.eolymp.course.ListSubmissionsOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xb4\x01\n\x12\x44\x65scribeSubmission\x12&.eolymp.course.DescribeSubmissionInput\x1a\'.eolymp.course.DescribeSubmissionOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12z\n\x0fWatchSubmission\x12#.eolymp.course.WatchSubmissionInput\x1a$.eolymp.course.WatchSubmissionOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read0\x01\x42/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.submission_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['CreateSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['CreateSubmission']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\343\n\030\212\343\n\024course:course:submit\202\323\344\223\002\016\"\014/submissions'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['ListSubmissions']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['ListSubmissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\016\022\014/submissions'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DescribeSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DescribeSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\026\212\343\n\022course:course:read\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['WatchSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read'
  _globals['_CREATESUBMISSIONINPUT']._serialized_start=222
  _globals['_CREATESUBMISSIONINPUT']._serialized_end=299
  _globals['_CREATESUBMISSIONOUTPUT']._serialized_start=301
  _globals['_CREATESUBMISSIONOUTPUT']._serialized_end=348
  _globals['_LISTSUBMISSIONSINPUT']._serialized_start=351
  _globals['_LISTSUBMISSIONSINPUT']._serialized_end=940
  _globals['_LISTSUBMISSIONSINPUT_FILTER']._serialized_start=466
  _globals['_LISTSUBMISSIONSINPUT_FILTER']._serialized_end=940
  _globals['_LISTSUBMISSIONSOUTPUT']._serialized_start=942
  _globals['_LISTSUBMISSIONSOUTPUT']._serialized_end=1047
  _globals['_DESCRIBESUBMISSIONINPUT']._serialized_start=1049
  _globals['_DESCRIBESUBMISSIONINPUT']._serialized_end=1097
  _globals['_DESCRIBESUBMISSIONOUTPUT']._serialized_start=1099
  _globals['_DESCRIBESUBMISSIONOUTPUT']._serialized_end=1171
  _globals['_WATCHSUBMISSIONINPUT']._serialized_start=1173
  _globals['_WATCHSUBMISSIONINPUT']._serialized_end=1218
  _globals['_WATCHSUBMISSIONOUTPUT']._serialized_start=1220
  _globals['_WATCHSUBMISSIONOUTPUT']._serialized_end=1289
  _globals['_SUBMISSIONSERVICE']._serialized_start=1292
  _globals['_SUBMISSIONSERVICE']._serialized_end=1939
# @@protoc_insertion_point(module_scope)



from eolymp.atlas import testing_feedback_pb2 as _testing_feedback_pb2
from eolymp.atlas import testing_scoring_pb2 as _testing_scoring_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Testset(_message.Message):
    __slots__ = ("id", "version_id", "index", "time_limit", "cpu_limit", "memory_limit", "file_size_limit", "dependencies", "dependency_mode", "scoring_mode", "feedback_policy")
    class DependencyMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_DEPENDENCY_MODE: _ClassVar[Testset.DependencyMode]
        FULLY_ACCEPTED: _ClassVar[Testset.DependencyMode]
        FIRST_POINT: _ClassVar[Testset.DependencyMode]
    UNKNOWN_DEPENDENCY_MODE: Testset.DependencyMode
    FULLY_ACCEPTED: Testset.DependencyMode
    FIRST_POINT: Testset.DependencyMode
    ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    TIME_LIMIT_FIELD_NUMBER: _ClassVar[int]
    CPU_LIMIT_FIELD_NUMBER: _ClassVar[int]
    MEMORY_LIMIT_FIELD_NUMBER: _ClassVar[int]
    FILE_SIZE_LIMIT_FIELD_NUMBER: _ClassVar[int]
    DEPENDENCIES_FIELD_NUMBER: _ClassVar[int]
    DEPENDENCY_MODE_FIELD_NUMBER: _ClassVar[int]
    SCORING_MODE_FIELD_NUMBER: _ClassVar[int]
    FEEDBACK_POLICY_FIELD_NUMBER: _ClassVar[int]
    id: str
    version_id: str
    index: int
    time_limit: int
    cpu_limit: int
    memory_limit: int
    file_size_limit: int
    dependencies: _containers.RepeatedScalarFieldContainer[int]
    dependency_mode: Testset.DependencyMode
    scoring_mode: _testing_scoring_pb2.ScoringMode
    feedback_policy: _testing_feedback_pb2.FeedbackPolicy
    def __init__(self, id: _Optional[str] = ..., version_id: _Optional[str] = ..., index: _Optional[int] = ..., time_limit: _Optional[int] = ..., cpu_limit: _Optional[int] = ..., memory_limit: _Optional[int] = ..., file_size_limit: _Optional[int] = ..., dependencies: _Optional[_Iterable[int]] = ..., dependency_mode: _Optional[_Union[Testset.DependencyMode, str]] = ..., scoring_mode: _Optional[_Union[_testing_scoring_pb2.ScoringMode, str]] = ..., feedback_policy: _Optional[_Union[_testing_feedback_pb2.FeedbackPolicy, str]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Solution(_message.Message):
    __slots__ = ("id", "name", "secret", "runtime", "source", "type", "status", "submission_id")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNSET: _ClassVar[Solution.Type]
        CORRECT: _ClassVar[Solution.Type]
        INCORRECT: _ClassVar[Solution.Type]
        WRONG_ANSWER: _ClassVar[Solution.Type]
        TIMEOUT: _ClassVar[Solution.Type]
        OVERFLOW: _ClassVar[Solution.Type]
        TIMEOUT_OR_ACCEPTED: _ClassVar[Solution.Type]
        OVERFLOW_OR_ACCEPTED: _ClassVar[Solution.Type]
        DONT_RUN: _ClassVar[Solution.Type]
        FAILURE: _ClassVar[Solution.Type]
    UNSET: Solution.Type
    CORRECT: Solution.Type
    INCORRECT: Solution.Type
    WRONG_ANSWER: Solution.Type
    TIMEOUT: Solution.Type
    OVERFLOW: Solution.Type
    TIMEOUT_OR_ACCEPTED: Solution.Type
    OVERFLOW_OR_ACCEPTED: Solution.Type
    DONT_RUN: Solution.Type
    FAILURE: Solution.Type
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Solution.Status]
        PENDING: _ClassVar[Solution.Status]
        PASS: _ClassVar[Solution.Status]
        FAIL: _ClassVar[Solution.Status]
        ERROR: _ClassVar[Solution.Status]
    UNKNOWN_STATUS: Solution.Status
    PENDING: Solution.Status
    PASS: Solution.Status
    FAIL: Solution.Status
    ERROR: Solution.Status
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    secret: bool
    runtime: str
    source: str
    type: Solution.Type
    status: Solution.Status
    submission_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., secret: bool = ..., runtime: _Optional[str] = ..., source: _Optional[str] = ..., type: _Optional[_Union[Solution.Type, str]] = ..., status: _Optional[_Union[Solution.Status, str]] = ..., submission_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/linked_account.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/community/linked_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/community/linked_account.proto\x12\x10\x65olymp.community\"\x96\x01\n\rLinkedAccount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x04type\x18\x02 \x01(\x0e\x32$.eolymp.community.LinkedAccount.Type\x12\x0e\n\x06issuer\x18\x03 \x01(\t\x12\x0f\n\x07subject\x18\x04 \x01(\t\"$\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\n\n\x06GOOGLE\x10\x01\x42\x35Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.linked_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_LINKEDACCOUNT']._serialized_start=60
  _globals['_LINKEDACCOUNT']._serialized_end=210
  _globals['_LINKEDACCOUNT_TYPE']._serialized_start=174
  _globals['_LINKEDACCOUNT_TYPE']._serialized_end=210
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.printer import printer_pb2 as _printer_pb2
from eolymp.printer import printer_job_pb2 as _printer_job_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreatePrinterInput(_message.Message):
    __slots__ = ("printer",)
    PRINTER_FIELD_NUMBER: _ClassVar[int]
    printer: _printer_pb2.Printer
    def __init__(self, printer: _Optional[_Union[_printer_pb2.Printer, _Mapping]] = ...) -> None: ...

class CreatePrinterOutput(_message.Message):
    __slots__ = ("printer_id",)
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    def __init__(self, printer_id: _Optional[str] = ...) -> None: ...

class UpdatePrinterInput(_message.Message):
    __slots__ = ("printer_id", "printer")
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    PRINTER_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    printer: _printer_pb2.Printer
    def __init__(self, printer_id: _Optional[str] = ..., printer: _Optional[_Union[_printer_pb2.Printer, _Mapping]] = ...) -> None: ...

class UpdatePrinterOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeletePrinterInput(_message.Message):
    __slots__ = ("printer_id",)
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    def __init__(self, printer_id: _Optional[str] = ...) -> None: ...

class DeletePrinterOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribePrinterInput(_message.Message):
    __slots__ = ("printer_id",)
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    def __init__(self, printer_id: _Optional[str] = ...) -> None: ...

class DescribePrinterOutput(_message.Message):
    __slots__ = ("printer",)
    PRINTER_FIELD_NUMBER: _ClassVar[int]
    printer: _printer_pb2.Printer
    def __init__(self, printer: _Optional[_Union[_printer_pb2.Printer, _Mapping]] = ...) -> None: ...

class ListPrintersInput(_message.Message):
    __slots__ = ("size", "offset", "search", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "status", "name")
        ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    SIZE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    size: int
    offset: int
    search: str
    filters: ListPrintersInput.Filter
    def __init__(self, size: _Optional[int] = ..., offset: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListPrintersInput.Filter, _Mapping]] = ...) -> None: ...

class ListPrintersOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_printer_pb2.Printer]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_printer_pb2.Printer, _Mapping]]] = ...) -> None: ...

class CreatePrinterJobInput(_message.Message):
    __slots__ = ("printer_id", "html")
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    HTML_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    html: str
    def __init__(self, printer_id: _Optional[str] = ..., html: _Optional[str] = ...) -> None: ...

class CreatePrinterJobOutput(_message.Message):
    __slots__ = ("job_id",)
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class DescribePrinterJobInput(_message.Message):
    __slots__ = ("printer_id", "job_id")
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    job_id: str
    def __init__(self, printer_id: _Optional[str] = ..., job_id: _Optional[str] = ...) -> None: ...

class DescribePrinterJobOutput(_message.Message):
    __slots__ = ("job",)
    JOB_FIELD_NUMBER: _ClassVar[int]
    job: _printer_job_pb2.Job
    def __init__(self, job: _Optional[_Union[_printer_job_pb2.Job, _Mapping]] = ...) -> None: ...

class ListPrinterJobsInput(_message.Message):
    __slots__ = ("printer_id", "offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "status")
        ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    offset: int
    size: int
    filters: ListPrinterJobsInput.Filter
    def __init__(self, printer_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListPrinterJobsInput.Filter, _Mapping]] = ...) -> None: ...

class ListPrinterJobsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_printer_job_pb2.Job]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_printer_job_pb2.Job, _Mapping]]] = ...) -> None: ...

class CancelPrinterJobInput(_message.Message):
    __slots__ = ("printer_id", "job_id")
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    job_id: str
    def __init__(self, printer_id: _Optional[str] = ..., job_id: _Optional[str] = ...) -> None: ...

class CancelPrinterJobOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdatePrinterJobInput(_message.Message):
    __slots__ = ("printer_id", "job_id", "job")
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    JOB_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    job_id: str
    job: _printer_job_pb2.Job
    def __init__(self, printer_id: _Optional[str] = ..., job_id: _Optional[str] = ..., job: _Optional[_Union[_printer_job_pb2.Job, _Mapping]] = ...) -> None: ...

class UpdatePrinterJobOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeletePrinterJobInput(_message.Message):
    __slots__ = ("printer_id", "job_id")
    PRINTER_ID_FIELD_NUMBER: _ClassVar[int]
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    printer_id: str
    job_id: str
    def __init__(self, printer_id: _Optional[str] = ..., job_id: _Optional[str] = ...) -> None: ...

class DeletePrinterJobOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Achievement(_message.Message):
    __slots__ = ("id", "value", "rarity", "name", "image_url", "summary", "cursor")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NO_EXTRA: _ClassVar[Achievement.Extra]
        SUMMARY_VALUE: _ClassVar[Achievement.Extra]
        SUMMARY_RENDER: _ClassVar[Achievement.Extra]
    NO_EXTRA: Achievement.Extra
    SUMMARY_VALUE: Achievement.Extra
    SUMMARY_RENDER: Achievement.Extra
    class Translation(_message.Message):
        __slots__ = ("id", "locale", "name", "summary")
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        SUMMARY_FIELD_NUMBER: _ClassVar[int]
        id: str
        locale: str
        name: str
        summary: _content_pb2.Content
        def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., name: _Optional[str] = ..., summary: _Optional[_Union[_content_pb2.Content, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    RARITY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    value: int
    rarity: int
    name: str
    image_url: str
    summary: _content_pb2.Content
    cursor: str
    def __init__(self, id: _Optional[str] = ..., value: _Optional[int] = ..., rarity: _Optional[int] = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., summary: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., cursor: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/submission_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/submission_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import submission_pb2 as eolymp_dot_atlas_dot_submission__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/atlas/submission_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/atlas/submission.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\x16SubmissionChangedEvent\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Submission\"W\n\x17SubmissionCompleteEvent\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\x12\x0e\n\x06update\x18\x02 \x01(\x08\"I\n\x15\x43reateSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"0\n\x17\x44\x65scribeSubmissionInput\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"x\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.atlas.Submission.Extra\"]\n\x14WatchSubmissionInput\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.atlas.Submission.Extra\"E\n\x15WatchSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Submission\"=\n\x15RetestSubmissionInput\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\x12\r\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\"\x18\n\x16RetestSubmissionOutput\"\xbc\x05\n\x14ListSubmissionsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.atlas.ListSubmissionsInput.Filter\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.atlas.Submission.Extra\x1a\x8a\x04\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\nproblem_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\t \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12;\n\x0csubmitted_at\x18\x04 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x31\n\x07runtime\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\x07verdict\x18\n \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x08 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\"i\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Submission\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"\x80\x01\n\x1c\x44\x65scribeSubmissionUsageInput\x12\x30\n\x0cperiod_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nperiod_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x93\x01\n\x1d\x44\x65scribeSubmissionUsageOutput\x12\x19\n\x11total_submissions\x18\x01 \x01(\r\x12\x1b\n\x13monthly_submissions\x18\x02 \x01(\r\x12\x1b\n\x13monthly_evaluations\x18\x03 \x01(\r\x12\x1d\n\x15\x61vailable_evaluations\x18\x04 \x01(\r\")\n\x13ListProblemTopInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\"?\n\x14ListProblemTopOutput\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.atlas.Submission2\x99\t\n\x11SubmissionService\x12\xa0\x01\n\x10\x43reateSubmission\x12#.eolymp.atlas.CreateSubmissionInput\x1a$.eolymp.atlas.CreateSubmissionOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02\x0e\"\x0c/submissions\x12\xb7\x01\n\x10RetestSubmission\x12#.eolymp.atlas.RetestSubmissionInput\x1a$.eolymp.atlas.RetestSubmissionOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xe3\n\x1a\x8a\xe3\n\x16\x61tlas:submission:write\x82\xd3\xe4\x93\x02%\"#/submissions/{submission_id}/retest\x12\xb5\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.atlas.DescribeSubmissionInput\x1a&.eolymp.atlas.DescribeSubmissionOutput\"P\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12{\n\x0fWatchSubmission\x12\".eolymp.atlas.WatchSubmissionInput\x1a#.eolymp.atlas.WatchSubmissionOutput\"\x1d\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read0\x01\x12\x9c\x01\n\x0fListSubmissions\x12\".eolymp.atlas.ListSubmissionsInput\x1a#.eolymp.atlas.ListSubmissionsOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\n\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xba\x01\n\x17\x44\x65scribeSubmissionUsage\x12*.eolymp.atlas.DescribeSubmissionUsageInput\x1a+.eolymp.atlas.DescribeSubmissionUsageOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x61tlas:submission:read\x82\xd3\xe4\x93\x02\x14\x12\x12/usage/submissions\x12\x95\x01\n\x0eListProblemTop\x12!.eolymp.atlas.ListProblemTopInput\x1a\".eolymp.atlas.ListProblemTopOutput\"<\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x1c\x12\x1a/problems/{problem_id}/topB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.submission_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['CreateSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['CreateSubmission']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002\016\"\014/submissions'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['RetestSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['RetestSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\343\n\032\212\343\n\026atlas:submission:write\202\323\344\223\002%\"#/submissions/{submission_id}/retest'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DescribeSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DescribeSubmission']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['WatchSubmission']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\031\212\343\n\025atlas:submission:read'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['ListSubmissions']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['ListSubmissions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\n\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\016\022\014/submissions'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DescribeSubmissionUsage']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['DescribeSubmissionUsage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025atlas:submission:read\202\323\344\223\002\024\022\022/usage/submissions'
  _globals['_SUBMISSIONSERVICE'].methods_by_name['ListProblemTop']._loaded_options = None
  _globals['_SUBMISSIONSERVICE'].methods_by_name['ListProblemTop']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\034\022\032/problems/{problem_id}/top'
  _globals['_SUBMISSIONCHANGEDEVENT']._serialized_start=253
  _globals['_SUBMISSIONCHANGEDEVENT']._serialized_end=360
  _globals['_SUBMISSIONCOMPLETEEVENT']._serialized_start=362
  _globals['_SUBMISSIONCOMPLETEEVENT']._serialized_end=449
  _globals['_CREATESUBMISSIONINPUT']._serialized_start=451
  _globals['_CREATESUBMISSIONINPUT']._serialized_end=524
  _globals['_CREATESUBMISSIONOUTPUT']._serialized_start=526
  _globals['_CREATESUBMISSIONOUTPUT']._serialized_end=573
  _globals['_DESCRIBESUBMISSIONINPUT']._serialized_start=575
  _globals['_DESCRIBESUBMISSIONINPUT']._serialized_end=623
  _globals['_DESCRIBESUBMISSIONOUTPUT']._serialized_start=625
  _globals['_DESCRIBESUBMISSIONOUTPUT']._serialized_end=745
  _globals['_WATCHSUBMISSIONINPUT']._serialized_start=747
  _globals['_WATCHSUBMISSIONINPUT']._serialized_end=840
  _globals['_WATCHSUBMISSIONOUTPUT']._serialized_start=842
  _globals['_WATCHSUBMISSIONOUTPUT']._serialized_end=911
  _globals['_RETESTSUBMISSIONINPUT']._serialized_start=913
  _globals['_RETESTSUBMISSIONINPUT']._serialized_end=974
  _globals['_RETESTSUBMISSIONOUTPUT']._serialized_start=976
  _globals['_RETESTSUBMISSIONOUTPUT']._serialized_end=1000
  _globals['_LISTSUBMISSIONSINPUT']._serialized_start=1003
  _globals['_LISTSUBMISSIONSINPUT']._serialized_end=1703
  _globals['_LISTSUBMISSIONSINPUT_FILTER']._serialized_start=1181
  _globals['_LISTSUBMISSIONSINPUT_FILTER']._serialized_end=1703
  _globals['_LISTSUBMISSIONSOUTPUT']._serialized_start=1705
  _globals['_LISTSUBMISSIONSOUTPUT']._serialized_end=1810
  _globals['_DESCRIBESUBMISSIONUSAGEINPUT']._serialized_start=1813
  _globals['_DESCRIBESUBMISSIONUSAGEINPUT']._serialized_end=1941
  _globals['_DESCRIBESUBMISSIONUSAGEOUTPUT']._serialized_start=1944
  _globals['_DESCRIBESUBMISSIONUSAGEOUTPUT']._serialized_end=2091
  _globals['_LISTPROBLEMTOPINPUT']._serialized_start=2093
  _globals['_LISTPROBLEMTOPINPUT']._serialized_end=2134
  _globals['_LISTPROBLEMTOPOUTPUT']._serialized_start=2136
  _globals['_LISTPROBLEMTOPOUTPUT']._serialized_end=2199
  _globals['_SUBMISSIONSERVICE']._serialized_start=2202
  _globals['_SUBMISSIONSERVICE']._serialized_end=3379
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/testing_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/testing_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import testing_checker_pb2 as eolymp_dot_atlas_dot_testing__checker__pb2
from eolymp.atlas import testing_config_pb2 as eolymp_dot_atlas_dot_testing__config__pb2
from eolymp.atlas import testing_interactor_pb2 as eolymp_dot_atlas_dot_testing__interactor__pb2
from eolymp.atlas import testing_test_pb2 as eolymp_dot_atlas_dot_testing__test__pb2
from eolymp.atlas import testing_testset_pb2 as eolymp_dot_atlas_dot_testing__testset__pb2
from eolymp.atlas import testing_validator_pb2 as eolymp_dot_atlas_dot_testing__validator__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/atlas/testing_checker.proto\x1a!eolymp/atlas/testing_config.proto\x1a%eolymp/atlas/testing_interactor.proto\x1a\x1f\x65olymp/atlas/testing_test.proto\x1a\"eolymp/atlas/testing_testset.proto\x1a$eolymp/atlas/testing_validator.proto\"\x88\x01\n\x19TestingConfigChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12+\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\x12*\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"\x7f\n\x16InteractorChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12(\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\x12\'\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\"v\n\x13\x43heckerChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12%\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Checker\x12$\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Checker\"|\n\x15ValidatorChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\'\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Validator\x12&\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x17.eolymp.atlas.Validator\"v\n\x13TestsetChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12%\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x12$\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"m\n\x10TestChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\"\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x12.eolymp.atlas.Test\x12!\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x12.eolymp.atlas.Test\"r\n\x15TestBatchChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\"\n\x06\x62\x65\x66ore\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\x12!\n\x05\x61\x66ter\x18\x03 \x03(\x0b\x32\x12.eolymp.atlas.Test\"G\n\x18UpdateTestingConfigInput\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"\x1b\n\x19UpdateTestingConfigOutput\"-\n\x1a\x44\x65scribeTestingConfigInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"J\n\x1b\x44\x65scribeTestingConfigOutput\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"<\n\x12UpdateCheckerInput\x12&\n\x07\x63hecker\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Checker\"\x15\n\x13UpdateCheckerOutput\"\'\n\x14\x44\x65scribeCheckerInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"?\n\x15\x44\x65scribeCheckerOutput\x12&\n\x07\x63hecker\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Checker\"E\n\x15UpdateInteractorInput\x12,\n\ninteractor\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\"\x18\n\x16UpdateInteractorOutput\"*\n\x17\x44\x65scribeInteractorInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"H\n\x18\x44\x65scribeInteractorOutput\x12,\n\ninteractor\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\"B\n\x14UpdateValidatorInput\x12*\n\tvalidator\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Validator\"\x17\n\x15UpdateValidatorOutput\")\n\x16\x44\x65scribeValidatorInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"E\n\x17\x44\x65scribeValidatorOutput\x12*\n\tvalidator\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Validator\"B\n\x11ListTestsetsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0f\n\x07version\x18\x64 \x01(\r\"I\n\x12ListTestsetsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Testset\";\n\x14\x44\x65scribeTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"?\n\x15\x44\x65scribeTestsetOutput\x12&\n\x07testset\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"<\n\x12\x43reateTestsetInput\x12&\n\x07testset\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"!\n\x13\x43reateTestsetOutput\x12\n\n\x02id\x18\x01 \x01(\t\"P\n\x12UpdateTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12&\n\x07testset\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"\x15\n\x13UpdateTestsetOutput\"(\n\x12\x44\x65leteTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteTestsetOutput\"$\n\x11ListExamplesInput\x12\x0f\n\x07version\x18\x64 \x01(\r\":\n\x12ListExamplesOutput\x12$\n\x08\x65xamples\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"5\n\x0eListTestsInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"C\n\x0fListTestsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"I\n\x11\x44\x65scribeTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"6\n\x12\x44\x65scribeTestOutput\x12 \n\x04test\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\"G\n\x0f\x43reateTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12 \n\x04test\x18\x03 \x01(\x0b\x32\x12.eolymp.atlas.Test\"#\n\x10\x43reateTestOutput\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"\x9a\x02\n\x0fUpdateTestInput\x12\x32\n\x05patch\x18\x05 \x03(\x0e\x32#.eolymp.atlas.UpdateTestInput.Patch\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\x12 \n\x04test\x18\x04 \x01(\x0b\x32\x12.eolymp.atlas.Test\"\x8b\x01\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x45XAMPLE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\t\n\x05SCORE\x10\x03\x12\t\n\x05INPUT\x10\x04\x12\n\n\x06\x41NSWER\x10\x05\x12\t\n\x05INDEX\x10\x08\x12\n\n\x06SECRET\x10\t\x12\x11\n\rEXAMPLE_INPUT\x10\x06\x12\x12\n\x0e\x45XAMPLE_ANSWER\x10\x07\"\x12\n\x10UpdateTestOutput\"6\n\x0f\x44\x65leteTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\"\x12\n\x10\x44\x65leteTestOutput2\xe4\x17\n\x0eTestingService\x12\xa2\x01\n\x13UpdateTestingConfig\x12&.eolymp.atlas.UpdateTestingConfigInput\x1a\'.eolymp.atlas.UpdateTestingConfigOutput\":\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x1a\x08/testing\x12\xa8\x01\n\x15\x44\x65scribeTestingConfig\x12(.eolymp.atlas.DescribeTestingConfigInput\x1a).eolymp.atlas.DescribeTestingConfigOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x12\x08/testing\x12\x90\x01\n\rUpdateChecker\x12 .eolymp.atlas.UpdateCheckerInput\x1a!.eolymp.atlas.UpdateCheckerOutput\":\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x1a\x08/checker\x12\x96\x01\n\x0f\x44\x65scribeChecker\x12\".eolymp.atlas.DescribeCheckerInput\x1a#.eolymp.atlas.DescribeCheckerOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x12\x08/checker\x12\x9c\x01\n\x10UpdateInteractor\x12#.eolymp.atlas.UpdateInteractorInput\x1a$.eolymp.atlas.UpdateInteractorOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\r\x1a\x0b/interactor\x12\xa2\x01\n\x12\x44\x65scribeInteractor\x12%.eolymp.atlas.DescribeInteractorInput\x1a&.eolymp.atlas.DescribeInteractorOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\r\x12\x0b/interactor\x12\x98\x01\n\x0fUpdateValidator\x12\".eolymp.atlas.UpdateValidatorInput\x1a#.eolymp.atlas.UpdateValidatorOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0c\x1a\n/validator\x12\x9e\x01\n\x11\x44\x65scribeValidator\x12$.eolymp.atlas.DescribeValidatorInput\x1a%.eolymp.atlas.DescribeValidatorOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0c\x12\n/validator\x12\x91\x01\n\rCreateTestset\x12 .eolymp.atlas.CreateTestsetInput\x1a!.eolymp.atlas.CreateTestsetOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0b\"\t/testsets\x12\x9e\x01\n\rUpdateTestset\x12 .eolymp.atlas.UpdateTestsetInput\x1a!.eolymp.atlas.UpdateTestsetOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/testsets/{testset_id}\x12\x9e\x01\n\rDeleteTestset\x12 .eolymp.atlas.DeleteTestsetInput\x1a!.eolymp.atlas.DeleteTestsetOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x18*\x16/testsets/{testset_id}\x12\xa4\x01\n\x0f\x44\x65scribeTestset\x12\".eolymp.atlas.DescribeTestsetInput\x1a#.eolymp.atlas.DescribeTestsetOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x18\x12\x16/testsets/{testset_id}\x12\x8e\x01\n\x0cListTestsets\x12\x1f.eolymp.atlas.ListTestsetsInput\x1a .eolymp.atlas.ListTestsetsOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0b\x12\t/testsets\x12\x9c\x01\n\nCreateTest\x12\x1d.eolymp.atlas.CreateTestInput\x1a\x1e.eolymp.atlas.CreateTestOutput\"O\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/testsets/{testset_id}/tests\x12\xa6\x01\n\nUpdateTest\x12\x1d.eolymp.atlas.UpdateTestInput\x1a\x1e.eolymp.atlas.UpdateTestOutput\"Y\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02(\x1a&/testsets/{testset_id}/tests/{test_id}\x12\xa6\x01\n\nDeleteTest\x12\x1d.eolymp.atlas.DeleteTestInput\x1a\x1e.eolymp.atlas.DeleteTestOutput\"Y\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02(*&/testsets/{testset_id}/tests/{test_id}\x12\xab\x01\n\x0c\x44\x65scribeTest\x12\x1f.eolymp.atlas.DescribeTestInput\x1a .eolymp.atlas.DescribeTestOutput\"X\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02(\x12&/testsets/{testset_id}/tests/{test_id}\x12\x98\x01\n\tListTests\x12\x1c.eolymp.atlas.ListTestsInput\x1a\x1d.eolymp.atlas.ListTestsOutput\"N\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1e\x12\x1c/testsets/{testset_id}/tests\x12\x8d\x01\n\x0cListExamples\x12\x1f.eolymp.atlas.ListExamplesInput\x1a .eolymp.atlas.ListExamplesOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0b\x12\t/examplesB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTestingConfig']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTestingConfig']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\032\010/testing'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTestingConfig']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTestingConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\022\010/testing'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateChecker']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateChecker']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\032\010/checker'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeChecker']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeChecker']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\022\010/checker'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateInteractor']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateInteractor']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\r\032\013/interactor'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeInteractor']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeInteractor']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\r\022\013/interactor'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateValidator']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateValidator']._serialized_options = b'\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\014\032\n/validator'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeValidator']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeValidator']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\014\022\n/validator'
  _globals['_TESTINGSERVICE'].methods_by_name['CreateTestset']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['CreateTestset']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\013\"\t/testsets'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTestset']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTestset']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\030\032\026/testsets/{testset_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['DeleteTestset']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DeleteTestset']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\030*\026/testsets/{testset_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTestset']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTestset']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\030\022\026/testsets/{testset_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['ListTestsets']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['ListTestsets']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\013\022\t/testsets'
  _globals['_TESTINGSERVICE'].methods_by_name['CreateTest']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['CreateTest']._serialized_options = b'\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\036\"\034/testsets/{testset_id}/tests'
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTest']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['UpdateTest']._serialized_options = b'\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002(\032&/testsets/{testset_id}/tests/{test_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['DeleteTest']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DeleteTest']._serialized_options = b'\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002(*&/testsets/{testset_id}/tests/{test_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTest']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['DescribeTest']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002(\022&/testsets/{testset_id}/tests/{test_id}'
  _globals['_TESTINGSERVICE'].methods_by_name['ListTests']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['ListTests']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\036\022\034/testsets/{testset_id}/tests'
  _globals['_TESTINGSERVICE'].methods_by_name['ListExamples']._loaded_options = None
  _globals['_TESTINGSERVICE'].methods_by_name['ListExamples']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\013\022\t/examples'
  _globals['_TESTINGCONFIGCHANGEDEVENT']._serialized_start=369
  _globals['_TESTINGCONFIGCHANGEDEVENT']._serialized_end=505
  _globals['_INTERACTORCHANGEDEVENT']._serialized_start=507
  _globals['_INTERACTORCHANGEDEVENT']._serialized_end=634
  _globals['_CHECKERCHANGEDEVENT']._serialized_start=636
  _globals['_CHECKERCHANGEDEVENT']._serialized_end=754
  _globals['_VALIDATORCHANGEDEVENT']._serialized_start=756
  _globals['_VALIDATORCHANGEDEVENT']._serialized_end=880
  _globals['_TESTSETCHANGEDEVENT']._serialized_start=882
  _globals['_TESTSETCHANGEDEVENT']._serialized_end=1000
  _globals['_TESTCHANGEDEVENT']._serialized_start=1002
  _globals['_TESTCHANGEDEVENT']._serialized_end=1111
  _globals['_TESTBATCHCHANGEDEVENT']._serialized_start=1113
  _globals['_TESTBATCHCHANGEDEVENT']._serialized_end=1227
  _globals['_UPDATETESTINGCONFIGINPUT']._serialized_start=1229
  _globals['_UPDATETESTINGCONFIGINPUT']._serialized_end=1300
  _globals['_UPDATETESTINGCONFIGOUTPUT']._serialized_start=1302
  _globals['_UPDATETESTINGCONFIGOUTPUT']._serialized_end=1329
  _globals['_DESCRIBETESTINGCONFIGINPUT']._serialized_start=1331
  _globals['_DESCRIBETESTINGCONFIGINPUT']._serialized_end=1376
  _globals['_DESCRIBETESTINGCONFIGOUTPUT']._serialized_start=1378
  _globals['_DESCRIBETESTINGCONFIGOUTPUT']._serialized_end=1452
  _globals['_UPDATECHECKERINPUT']._serialized_start=1454
  _globals['_UPDATECHECKERINPUT']._serialized_end=1514
  _globals['_UPDATECHECKEROUTPUT']._serialized_start=1516
  _globals['_UPDATECHECKEROUTPUT']._serialized_end=1537
  _globals['_DESCRIBECHECKERINPUT']._serialized_start=1539
  _globals['_DESCRIBECHECKERINPUT']._serialized_end=1578
  _globals['_DESCRIBECHECKEROUTPUT']._serialized_start=1580
  _globals['_DESCRIBECHECKEROUTPUT']._serialized_end=1643
  _globals['_UPDATEINTERACTORINPUT']._serialized_start=1645
  _globals['_UPDATEINTERACTORINPUT']._serialized_end=1714
  _globals['_UPDATEINTERACTOROUTPUT']._serialized_start=1716
  _globals['_UPDATEINTERACTOROUTPUT']._serialized_end=1740
  _globals['_DESCRIBEINTERACTORINPUT']._serialized_start=1742
  _globals['_DESCRIBEINTERACTORINPUT']._serialized_end=1784
  _globals['_DESCRIBEINTERACTOROUTPUT']._serialized_start=1786
  _globals['_DESCRIBEINTERACTOROUTPUT']._serialized_end=1858
  _globals['_UPDATEVALIDATORINPUT']._serialized_start=1860
  _globals['_UPDATEVALIDATORINPUT']._serialized_end=1926
  _globals['_UPDATEVALIDATOROUTPUT']._serialized_start=1928
  _globals['_UPDATEVALIDATOROUTPUT']._serialized_end=1951
  _globals['_DESCRIBEVALIDATORINPUT']._serialized_start=1953
  _globals['_DESCRIBEVALIDATORINPUT']._serialized_end=1994
  _globals['_DESCRIBEVALIDATOROUTPUT']._serialized_start=1996
  _globals['_DESCRIBEVALIDATOROUTPUT']._serialized_end=2065
  _globals['_LISTTESTSETSINPUT']._serialized_start=2067
  _globals['_LISTTESTSETSINPUT']._serialized_end=2133
  _globals['_LISTTESTSETSOUTPUT']._serialized_start=2135
  _globals['_LISTTESTSETSOUTPUT']._serialized_end=2208
  _globals['_DESCRIBETESTSETINPUT']._serialized_start=2210
  _globals['_DESCRIBETESTSETINPUT']._serialized_end=2269
  _globals['_DESCRIBETESTSETOUTPUT']._serialized_start=2271
  _globals['_DESCRIBETESTSETOUTPUT']._serialized_end=2334
  _globals['_CREATETESTSETINPUT']._serialized_start=2336
  _globals['_CREATETESTSETINPUT']._serialized_end=2396
  _globals['_CREATETESTSETOUTPUT']._serialized_start=2398
  _globals['_CREATETESTSETOUTPUT']._serialized_end=2431
  _globals['_UPDATETESTSETINPUT']._serialized_start=2433
  _globals['_UPDATETESTSETINPUT']._serialized_end=2513
  _globals['_UPDATETESTSETOUTPUT']._serialized_start=2515
  _globals['_UPDATETESTSETOUTPUT']._serialized_end=2536
  _globals['_DELETETESTSETINPUT']._serialized_start=2538
  _globals['_DELETETESTSETINPUT']._serialized_end=2578
  _globals['_DELETETESTSETOUTPUT']._serialized_start=2580
  _globals['_DELETETESTSETOUTPUT']._serialized_end=2601
  _globals['_LISTEXAMPLESINPUT']._serialized_start=2603
  _globals['_LISTEXAMPLESINPUT']._serialized_end=2639
  _globals['_LISTEXAMPLESOUTPUT']._serialized_start=2641
  _globals['_LISTEXAMPLESOUTPUT']._serialized_end=2699
  _globals['_LISTTESTSINPUT']._serialized_start=2701
  _globals['_LISTTESTSINPUT']._serialized_end=2754
  _globals['_LISTTESTSOUTPUT']._serialized_start=2756
  _globals['_LISTTESTSOUTPUT']._serialized_end=2823
  _globals['_DESCRIBETESTINPUT']._serialized_start=2825
  _globals['_DESCRIBETESTINPUT']._serialized_end=2898
  _globals['_DESCRIBETESTOUTPUT']._serialized_start=2900
  _globals['_DESCRIBETESTOUTPUT']._serialized_end=2954
  _globals['_CREATETESTINPUT']._serialized_start=2956
  _globals['_CREATETESTINPUT']._serialized_end=3027
  _globals['_CREATETESTOUTPUT']._serialized_start=3029
  _globals['_CREATETESTOUTPUT']._serialized_end=3064
  _globals['_UPDATETESTINPUT']._serialized_start=3067
  _globals['_UPDATETESTINPUT']._serialized_end=3349
  _globals['_UPDATETESTINPUT_PATCH']._serialized_start=3210
  _globals['_UPDATETESTINPUT_PATCH']._serialized_end=3349
  _globals['_UPDATETESTOUTPUT']._serialized_start=3351
  _globals['_UPDATETESTOUTPUT']._serialized_end=3369
  _globals['_DELETETESTINPUT']._serialized_start=3371
  _globals['_DELETETESTINPUT']._serialized_end=3425
  _globals['_DELETETESTOUTPUT']._serialized_start=3427
  _globals['_DELETETESTOUTPUT']._serialized_end=3445
  _globals['_TESTINGSERVICE']._serialized_start=3448
  _globals['_TESTINGSERVICE']._serialized_end=6492
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/taxonomy/institution.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/taxonomy/institution.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/taxonomy/institution.proto\x12\x0f\x65olymp.taxonomy\"\xe2\x05\n\x0bInstitution\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x63ronym\x18\x04 \x01(\t\x12\x12\n\nlocal_name\x18\x03 \x01(\t\x12\x15\n\rlocal_acronym\x18\x05 \x01(\t\x12\x10\n\x08logo_url\x18\x14 \x01(\t\x12;\n\ngovernance\x18\n \x01(\x0e\x32\'.eolymp.taxonomy.Institution.Governance\x12\x31\n\x05level\x18\x0b \x01(\x0e\x32\".eolymp.taxonomy.Institution.Level\x12/\n\x04type\x18\x0c \x01(\x0e\x32!.eolymp.taxonomy.Institution.Type\x12\x12\n\ncountry_id\x18\x1e \x01(\t\x12\x11\n\tregion_id\x18\x1f \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18  \x01(\t\x12\x36\n\x05links\x18) \x03(\x0b\x32\'.eolymp.taxonomy.Institution.LinksEntry\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n\nGovernance\x12\x16\n\x12UNKNOWN_GOVERNANCE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\x12\x0b\n\x07\x43HARTER\x10\x03\"S\n\x05Level\x12\x11\n\rUNKNOWN_LEVEL\x10\x00\x12\r\n\tPRESCHOOL\x10\x01\x12\x0b\n\x07PRIMARY\x10\x02\x12\r\n\tSECONDARY\x10\x03\x12\x0c\n\x08TERTIARY\x10\x04\"\x8a\x01\n\x04Type\x12\x10\n\x0cUNKNOWN_TYPE\x10\x00\x12\x10\n\x0cKINDERGARTEN\x10\x01\x12\n\n\x06SCHOOL\x10\x02\x12\n\n\x06LYCEUM\x10\x03\x12\r\n\tGYMNASIUM\x10\x04\x12\x0b\n\x07\x43OLLEGE\x10\x05\x12\r\n\tINSTITUTE\x10\x06\x12\x0e\n\nUNIVERSITY\x10\x07\x12\x0b\n\x07\x41\x43\x41\x44\x45MY\x10\x08\x42\x33Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.taxonomy.institution_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/taxonomy;taxonomy'
  _globals['_INSTITUTION_LINKSENTRY']._loaded_options = None
  _globals['_INSTITUTION_LINKSENTRY']._serialized_options = b'8\001'
  _globals['_INSTITUTION']._serialized_start=55
  _globals['_INSTITUTION']._serialized_end=793
  _globals['_INSTITUTION_LINKSENTRY']._serialized_start=447
  _globals['_INSTITUTION_LINKSENTRY']._serialized_end=491
  _globals['_INSTITUTION_GOVERNANCE']._serialized_start=493
  _globals['_INSTITUTION_GOVERNANCE']._serialized_end=567
  _globals['_INSTITUTION_LEVEL']._serialized_start=569
  _globals['_INSTITUTION_LEVEL']._serialized_end=652
  _globals['_INSTITUTION_TYPE']._serialized_start=655
  _globals['_INSTITUTION_TYPE']._serialized_end=793
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/script_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/script_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import script_pb2 as eolymp_dot_atlas_dot_script__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/atlas/script_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x19\x65olymp/atlas/script.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"s\n\x12ScriptChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12$\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x14.eolymp.atlas.Script\x12#\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x14.eolymp.atlas.Script\"9\n\x11\x43reateScriptInput\x12$\n\x06script\x18\x01 \x01(\x0b\x32\x14.eolymp.atlas.Script\"\'\n\x12\x43reateScriptOutput\x12\x11\n\tscript_id\x18\x01 \x01(\t\"\xd2\x01\n\x11UpdateScriptInput\x12\x34\n\x05patch\x18\x01 \x03(\x0e\x32%.eolymp.atlas.UpdateScriptInput.Patch\x12\x11\n\tscript_id\x18\x02 \x01(\t\x12$\n\x06script\x18\x03 \x01(\x0b\x32\x14.eolymp.atlas.Script\"N\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\n\n\x06SECRET\x10\x02\x12\x0b\n\x07RUNTIME\x10\x03\x12\x0e\n\nSOURCE_URL\x10\x04\x12\t\n\x05\x46ILES\x10\x05\"\x14\n\x12UpdateScriptOutput\"&\n\x11\x44\x65leteScriptInput\x12\x11\n\tscript_id\x18\x01 \x01(\t\"\x14\n\x12\x44\x65leteScriptOutput\"e\n\x13\x44\x65scribeScriptInput\x12\x11\n\tscript_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.atlas.Script.Extra\"<\n\x14\x44\x65scribeScriptOutput\x12$\n\x06script\x18\x01 \x01(\x0b\x32\x14.eolymp.atlas.Script\"\xca\x03\n\x10ListScriptsInput\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.atlas.ListScriptsInput.Filter\x12\x35\n\x04sort\x18\x32 \x01(\x0e\x32\'.eolymp.atlas.ListScriptsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.atlas.Script.Extra\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x0b \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x31\n\x07runtime\x18\x0c \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x14\n\x08Sortable\x12\x08\n\x04NAME\x10\x00\"G\n\x11ListScriptsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.atlas.Script2\x84\x06\n\rScriptService\x12\x8d\x01\n\x0c\x43reateScript\x12\x1f.eolymp.atlas.CreateScriptInput\x1a .eolymp.atlas.CreateScriptOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\n\x1a\x08/scripts\x12\x99\x01\n\x0cUpdateScript\x12\x1f.eolymp.atlas.UpdateScriptInput\x1a .eolymp.atlas.UpdateScriptOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x16\x1a\x14/scripts/{script_id}\x12\x99\x01\n\x0c\x44\x65leteScript\x12\x1f.eolymp.atlas.DeleteScriptInput\x1a .eolymp.atlas.DeleteScriptOutput\"F\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x16*\x14/scripts/{script_id}\x12\x9e\x01\n\x0e\x44\x65scribeScript\x12!.eolymp.atlas.DescribeScriptInput\x1a\".eolymp.atlas.DescribeScriptOutput\"E\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x16\x12\x14/scripts/{script_id}\x12\x89\x01\n\x0bListScripts\x12\x1e.eolymp.atlas.ListScriptsInput\x1a\x1f.eolymp.atlas.ListScriptsOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\n\x12\x08/scriptsB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.script_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SCRIPTSERVICE'].methods_by_name['CreateScript']._loaded_options = None
  _globals['_SCRIPTSERVICE'].methods_by_name['CreateScript']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\n\032\010/scripts'
  _globals['_SCRIPTSERVICE'].methods_by_name['UpdateScript']._loaded_options = None
  _globals['_SCRIPTSERVICE'].methods_by_name['UpdateScript']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\026\032\024/scripts/{script_id}'
  _globals['_SCRIPTSERVICE'].methods_by_name['DeleteScript']._loaded_options = None
  _globals['_SCRIPTSERVICE'].methods_by_name['DeleteScript']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\026*\024/scripts/{script_id}'
  _globals['_SCRIPTSERVICE'].methods_by_name['DescribeScript']._loaded_options = None
  _globals['_SCRIPTSERVICE'].methods_by_name['DescribeScript']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\026\022\024/scripts/{script_id}'
  _globals['_SCRIPTSERVICE'].methods_by_name['ListScripts']._loaded_options = None
  _globals['_SCRIPTSERVICE'].methods_by_name['ListScripts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\n\022\010/scripts'
  _globals['_SCRIPTCHANGEDEVENT']._serialized_start=246
  _globals['_SCRIPTCHANGEDEVENT']._serialized_end=361
  _globals['_CREATESCRIPTINPUT']._serialized_start=363
  _globals['_CREATESCRIPTINPUT']._serialized_end=420
  _globals['_CREATESCRIPTOUTPUT']._serialized_start=422
  _globals['_CREATESCRIPTOUTPUT']._serialized_end=461
  _globals['_UPDATESCRIPTINPUT']._serialized_start=464
  _globals['_UPDATESCRIPTINPUT']._serialized_end=674
  _globals['_UPDATESCRIPTINPUT_PATCH']._serialized_start=596
  _globals['_UPDATESCRIPTINPUT_PATCH']._serialized_end=674
  _globals['_UPDATESCRIPTOUTPUT']._serialized_start=676
  _globals['_UPDATESCRIPTOUTPUT']._serialized_end=696
  _globals['_DELETESCRIPTINPUT']._serialized_start=698
  _globals['_DELETESCRIPTINPUT']._serialized_end=736
  _globals['_DELETESCRIPTOUTPUT']._serialized_start=738
  _globals['_DELETESCRIPTOUTPUT']._serialized_end=758
  _globals['_DESCRIBESCRIPTINPUT']._serialized_start=760
  _globals['_DESCRIBESCRIPTINPUT']._serialized_end=861
  _globals['_DESCRIBESCRIPTOUTPUT']._serialized_start=863
  _globals['_DESCRIBESCRIPTOUTPUT']._serialized_end=923
  _globals['_LISTSCRIPTSINPUT']._serialized_start=926
  _globals['_LISTSCRIPTSINPUT']._serialized_end=1384
  _globals['_LISTSCRIPTSINPUT_FILTER']._serialized_start=1209
  _globals['_LISTSCRIPTSINPUT_FILTER']._serialized_end=1362
  _globals['_LISTSCRIPTSINPUT_SORTABLE']._serialized_start=1364
  _globals['_LISTSCRIPTSINPUT_SORTABLE']._serialized_end=1384
  _globals['_LISTSCRIPTSOUTPUT']._serialized_start=1386
  _globals['_LISTSCRIPTSOUTPUT']._serialized_end=1457
  _globals['_SCRIPTSERVICE']._serialized_start=1460
  _globals['_SCRIPTSERVICE']._serialized_end=2232
# @@protoc_insertion_point(module_scope)



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AutoReply(_message.Message):
    __slots__ = ("id", "locale", "name", "message", "labels")
    ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    id: str
    locale: str
    name: str
    message: _content_pb2.Content
    labels: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., locale: _Optional[str] = ..., name: _Optional[str] = ..., message: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., labels: _Optional[_Iterable[str]] = ...) -> None: ...
